@@ -14,6 +14,7 @@ from ..core import (
     eveimageserver,
     eveitems,
     evemicros,
+    evesdeapi,
     eveskinserver,
     evewho,
     evexml,
@@ -22,7 +23,11 @@ from ..core import (
 from ..models import EveEntity
 from ..utils import NoSocketsTestCase
 from .testdata.esi import EsiClientStub
-from .testdata.factories import create_eve_entity, create_evemicros_request
+from .testdata.factories import (
+    create_eve_entity,
+    create_evemicros_response,
+    create_evesdeapi_response,
+)
 
 
 class TestDotlan(TestCase):
@@ -252,7 +257,7 @@ class TestEveMicrosNearestCelestial(TestCase):
         requests_mocker.register_uri(
             "GET",
             url="https://www.kalkoken.org/apps/evemicros/eveUniverse.php?nearestCelestials=30002682,660502472160,-130687672800,-813545103840",
-            json=create_evemicros_request(40170698, 50011472, 40170697),
+            json=create_evemicros_response(40170698, 50011472, 40170697),
         )
         # when
         result = evemicros.nearest_celestial(
@@ -270,7 +275,7 @@ class TestEveMicrosNearestCelestial(TestCase):
         requests_mocker.register_uri(
             "GET",
             url="https://www.kalkoken.org/apps/evemicros/eveUniverse.php?nearestCelestials=99,1,2,3",
-            json=create_evemicros_request(40170698, 50011472, 40170697),
+            json=create_evemicros_response(40170698, 50011472, 40170697),
         )
         evemicros.nearest_celestial(solar_system_id=99, x=1, y=2, z=3)
         # when
@@ -284,7 +289,7 @@ class TestEveMicrosNearestCelestial(TestCase):
         requests_mocker.register_uri(
             "GET",
             url="https://www.kalkoken.org/apps/evemicros/eveUniverse.php?nearestCelestials=30002682,1,2,3",
-            json=create_evemicros_request(),
+            json=create_evemicros_response(),
         )
         # when
         result = evemicros.nearest_celestial(solar_system_id=30002682, x=1, y=2, z=3)
@@ -296,7 +301,7 @@ class TestEveMicrosNearestCelestial(TestCase):
         requests_mocker.register_uri(
             "GET",
             url="https://www.kalkoken.org/apps/evemicros/eveUniverse.php?nearestCelestials=30002682,1,2,3",
-            json=create_evemicros_request(40170698, 50011472, ok=False),
+            json=create_evemicros_response(40170698, 50011472, ok=False),
         )
         # when
         result = evemicros.nearest_celestial(solar_system_id=30002682, x=1, y=2, z=3)
@@ -319,7 +324,7 @@ class TestEveMicrosNearestCelestial(TestCase):
         requests_mocker.register_uri(
             "GET",
             url="https://www.kalkoken.org/apps/evemicros/eveUniverse.php?nearestCelestials=30002682,660502472160,-130687672800,-813545103840",
-            json=create_evemicros_request(40170698, 50011472, 40170697, 40170699),
+            json=create_evemicros_response(40170698, 50011472, 40170697, 40170699),
         )
         # when
         result = evemicros.nearest_celestial(
@@ -499,3 +504,100 @@ class TestZkillboard(TestCase):
             zkillboard.solar_system_url(12345678),
             "https://zkillboard.com/system/12345678/",
         )
+
+
+@requests_mock.Mocker()
+class TestEveSdeApiNearestCelestial(TestCase):
+    _BASE_URL = "https://evesdeapi.kalkoken.net/latest"
+
+    def setUp(self) -> None:
+        cache.clear()
+
+    def test_should_return_item_from_api(self, requests_mocker):
+        # given
+        requests_mocker.register_uri(
+            "GET",
+            url=(
+                f"{self._BASE_URL}/universe/systems/30002682/nearest_celestials"
+                "?x=660502472160&y=-130687672800&z=-813545103840"
+            ),
+            json=create_evesdeapi_response(40170698, 50011472, 40170697),
+        )
+        # when
+        result = evesdeapi.nearest_celestial(
+            solar_system_id=30002682, x=660502472160, y=-130687672800, z=-813545103840
+        )
+        # then
+        self.assertEqual(result.id, 40170698)
+        self.assertEqual(result.name, "Colelie VI - Asteroid Belt 1")
+        self.assertEqual(result.type_id, 15)
+        self.assertEqual(result.distance, 701983769)
+
+    def test_should_return_item_from_cache(self, requests_mocker):
+        # given
+        requests_mocker.register_uri(
+            "GET",
+            url=(
+                f"{self._BASE_URL}/universe/systems/30002682/nearest_celestials"
+                "?x=660502472160&y=-130687672800&z=-813545103840"
+            ),
+            json=create_evesdeapi_response(40170698, 50011472, 40170697),
+        )
+        evesdeapi.nearest_celestial(
+            solar_system_id=30002682, x=660502472160, y=-130687672800, z=-813545103840
+        )  # when
+        result = evesdeapi.nearest_celestial(
+            solar_system_id=30002682, x=660502472160, y=-130687672800, z=-813545103840
+        )  # then
+        self.assertEqual(result.id, 40170698)
+        self.assertEqual(requests_mocker.call_count, 1)
+
+    def test_should_return_none_if_nothing_found(self, requests_mocker):
+        # given
+        requests_mocker.register_uri(
+            "GET",
+            url=(
+                f"{self._BASE_URL}/universe/systems/30002682/nearest_celestials"
+                "?x=1&y=2&z=3"
+            ),
+            json=create_evesdeapi_response(),
+        )
+        # when
+        result = evesdeapi.nearest_celestial(solar_system_id=30002682, x=1, y=2, z=3)
+        # then
+        self.assertIsNone(result)
+
+    def test_should_raise_exception_for_http_errors(self, requests_mocker):
+        # given
+        requests_mocker.register_uri(
+            "GET",
+            url=(
+                f"{self._BASE_URL}/universe/systems/30002682/nearest_celestials"
+                "?x=1&y=2&z=3"
+            ),
+            status_code=500,
+        )
+        # when
+        with self.assertRaises(HTTPError):
+            evesdeapi.nearest_celestial(solar_system_id=30002682, x=1, y=2, z=3)
+
+    def test_should_return_moon_from_api(self, requests_mocker):
+        # given
+        requests_mocker.register_uri(
+            "GET",
+            url=(
+                f"{self._BASE_URL}/universe/systems/30002682/nearest_celestials"
+                "?x=660502472160&y=-130687672800&z=-813545103840&group_id=8"
+            ),
+            json=create_evesdeapi_response(40170699),
+        )
+        # when
+        result = evesdeapi.nearest_celestial(
+            solar_system_id=30002682,
+            x=660502472160,
+            y=-130687672800,
+            z=-813545103840,
+            group_id=EveGroupId.MOON,
+        )
+        # then
+        self.assertEqual(result.id, 40170699)
